{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#bwa_input_prepare.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/bwa-bundle:dev"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "samtools view -H $(inputs.input_bam.path) | grep ^@RG > rg.txt\nif [ $(inputs.input_bam.size) -gt $(inputs.max_siz) ]; then\n  bamtofastq tryoq=1 filename=$(inputs.input_bam.path) | split -dl 500000000 - reads-\n  ls reads-* | xargs -i mv {} {}.fq\nfi"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#bwa_input_prepare.cwl/bwa_input_prepare/input_bam"
                },
                {
                    "type": "int",
                    "default": 10000000000,
                    "id": "#bwa_input_prepare.cwl/bwa_input_prepare/max_siz"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.fq",
                        "outputEval": "${\n  if( inputs.input_bam.size < inputs.max_siz ) return [inputs.input_bam]\n  else return self\n}"
                    },
                    "id": "#bwa_input_prepare.cwl/bwa_input_prepare/output"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "rg.txt"
                    },
                    "id": "#bwa_input_prepare.cwl/bwa_input_prepare/rg"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#bwa_mem_split.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 50000,
                    "coresMin": 18
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "images.sbgenomics.com/bogdang/bwa-kf-bundle:0.1.17"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "if [ $(inputs.reads.nameext) = \".bam\" ]; then\n  CMD='/opt/biobambam2/2.0.87-release-20180301132713/x86_64-etch-linux-gnu/bin/bamtofastq tryoq=1 filename=$(inputs.reads.path)'\nelse\n  CMD='cat $(inputs.reads.path)'\nfi\n$CMD | bwa mem -K 100000000 -p -v 3 -t 18 -Y $(inputs.ref.path) -R '$(inputs.rg)' - | /opt/samblaster/samblaster -i /dev/stdin -o /dev/stdout | /opt/sambamba_0.6.3/sambamba_v0.6.3 view -t 18 -f bam -l 0 -S /dev/stdin | /opt/sambamba_0.6.3/sambamba_v0.6.3 sort -t 18 --natural-sort -m 35GiB --tmpdir ./ -o $(inputs.reads.nameroot).unsorted.bam -l 5 /dev/stdin"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#bwa_mem_split.cwl/bwa_mem_split/reads"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        ".64.alt",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#bwa_mem_split.cwl/bwa_mem_split/ref"
                },
                {
                    "type": "string",
                    "id": "#bwa_mem_split.cwl/bwa_mem_split/rg"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "id": "#bwa_mem_split.cwl/bwa_mem_split/output"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "id": "#expression_preparerg.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#expression_preparerg.cwl/expression_preparerg/rg"
                },
                {
                    "type": "string",
                    "id": "#expression_preparerg.cwl/expression_preparerg/sample"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#expression_preparerg.cwl/expression_preparerg/rg_str"
                }
            ],
            "expression": "${ var arr = inputs.rg.contents.split('\\n')[0].split('\\t'); for (var i=1; i<arr.length; i++){ if (arr[i].startsWith('SM')){ arr[i] = 'SM:' + inputs.sample; } } return {rg_str: arr.join('\\\\t')}; }"
        },
        {
            "class": "Workflow",
            "id": "#main",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/base_name"
                },
                {
                    "type": "File",
                    "id": "#main/indexed_reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/input_reads"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bwa_mem_split/output",
                    "id": "#main/aligned_bams"
                }
            ],
            "steps": [
                {
                    "run": "#bwa_input_prepare.cwl",
                    "in": [
                        {
                            "source": "#main/input_reads",
                            "id": "#main/bwa_input_prepare/input_bam"
                        }
                    ],
                    "out": [
                        "#main/bwa_input_prepare/output",
                        "#main/bwa_input_prepare/rg"
                    ],
                    "id": "#main/bwa_input_prepare"
                },
                {
                    "run": "#bwa_mem_split.cwl",
                    "in": [
                        {
                            "source": "#main/bwa_input_prepare/output",
                            "id": "#main/bwa_mem_split/reads"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/bwa_mem_split/ref"
                        },
                        {
                            "source": "#main/expression_updatergsample/rg_str",
                            "id": "#main/bwa_mem_split/rg"
                        }
                    ],
                    "scatter": [
                        "#main/bwa_mem_split/reads"
                    ],
                    "out": [
                        "#main/bwa_mem_split/output"
                    ],
                    "id": "#main/bwa_mem_split"
                },
                {
                    "run": "#expression_preparerg.cwl",
                    "in": [
                        {
                            "source": "#main/bwa_input_prepare/rg",
                            "id": "#main/expression_updatergsample/rg"
                        },
                        {
                            "source": "#main/base_name",
                            "id": "#main/expression_updatergsample/sample"
                        }
                    ],
                    "out": [
                        "#main/expression_updatergsample/rg_str"
                    ],
                    "id": "#main/expression_updatergsample"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0"
}
